summaryrefslogtreecommitdiffstats
path: root/games/snake
diff options
context:
space:
mode:
authorpjanzen <pjanzen@openbsd.org>2000-04-21 03:10:24 +0000
committerpjanzen <pjanzen@openbsd.org>2000-04-21 03:10:24 +0000
commit2b76410af07b628d035b074f2ca1b999c305871d (patch)
tree1df3191abbc81d0688f360727d932e5a73cb0ea2 /games/snake
parentFix memory leak per connection. Report from Andy Spiegl <Andy@Spiegl.de> (diff)
downloadwireguard-openbsd-2b76410af07b628d035b074f2ca1b999c305871d.tar.xz
wireguard-openbsd-2b76410af07b628d035b074f2ca1b999c305871d.zip
documentation: refer to terminfo, not termcap, where appropriate.
Diffstat (limited to 'games/snake')
-rw-r--r--games/snake/move.c10
1 files changed, 5 insertions, 5 deletions
diff --git a/games/snake/move.c b/games/snake/move.c
index df8d50e1706..ecf8c55d833 100644
--- a/games/snake/move.c
+++ b/games/snake/move.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: move.c,v 1.1 1999/03/13 02:08:09 pjanzen Exp $ */
+/* $OpenBSD: move.c,v 1.2 2000/04/21 03:10:31 pjanzen Exp $ */
/* $NetBSD: move.c,v 1.12 1996/05/19 20:22:09 pk Exp $ */
/*
@@ -38,7 +38,7 @@
#if 0
static char sccsid[] = "@(#)move.c 8.1 (Berkeley) 7/19/93";
#else
-static char rcsid[] = "$OpenBSD: move.c,v 1.1 1999/03/13 02:08:09 pjanzen Exp $";
+static char rcsid[] = "$OpenBSD: move.c,v 1.2 2000/04/21 03:10:31 pjanzen Exp $";
#endif
#endif /* not lint */
@@ -85,7 +85,7 @@ static char rcsid[] = "$OpenBSD: move.c,v 1.1 1999/03/13 02:08:09 pjanzen Exp $"
* otherwise, dumps it.(no wrap-around).
*
* getcap() initializes strings for later calls.
* cap(string) outputs the string designated in the termcap
* data base. (Should not move the cursor.)
*
* cook() returns the terminal to initial state.
@@ -279,7 +279,7 @@ right(sp)
field = cursor.col >> 3;
/*
* This code is useful for a terminal which wraps around on backspaces.
* (Mine does.) Unfortunately, this is not specified in termcap, and
* most terminals don't work that way. (Of course, most terminals
* have addressible cursors, too).
*/
@@ -594,7 +594,7 @@ getcap()
errx(1, "No TERM in environment");
switch (tgetent(tbuf, term)) {
case -1:
- errx(2, "Cannot open termcap file");
+ errx(2, "Cannot open terminfo file");
case 0:
errx(3, "unknown terminal `%s'", term);
}
@@ -85,7 +85,7 @@ static char rcsid[] = "$OpenBSD: move.c,v 1.1 1999/03/13 02:08:09 pjanzen Exp $"
*
* getcap() initializes strings for later calls.
- * cap(string) outputs the string designated in the termcap
+ * cap(string) outputs the string designated in the terminfo
* data base. (Should not move the cursor.)
*
@@ -279,7 +279,7 @@ right(sp)
/*
* This code is useful for a terminal which wraps around on backspaces.
- * (Mine does.) Unfortunately, this is not specified in termcap, and
+ * (Mine does.) Unfortunately, this is not specified in terminfo, and
* most terminals don't work that way. (Of course, most terminals
* have addressible cursors, too).